We welcome your contributions to CastleCMS! whether code, design, reporting issues, documentation, feature ideas

Please note that Wildcard Corp. offers and maintains this CastleCMS repo in the spirit of open source and community.

We maintain a private CastleCMS Advantage edition for paying enterprise clients.
This Advantage edition includes features that will be of interest primarily to clients running large websites, intranets, and portals.

We are committed to continuing to develop and enhance CastleCMS (both Community and Advantage editions, as well as its Castle Cloud managed hosted solution).

We appreciate and support the Plone community and project (plone.com and plone.org).

We reserve the right not to accept specific pull requests and to reject specific issues.
